@@ -1,6 +1,8 @@
 
 """
-Maintains version and package information for deployment.
+MainI:wq!
+:wsq!
+tains version a1d package information for deployment.
 """
 
 ##########################################################################
@@ -10,7 +12,7 @@ Maintains version and package information for deployment.
 __version_info__ = {
     "major": 0,
     "minor": 5,
-    "micro": 275,    
+    "micro": 282,
     "releaselevel": "alpha",
     "post": 0,
     "serial": 1,
